==> homelawnsecurity-0.0.5.1-sources.jar: net/db64/homelawnsecurity/entity/client/zombie/TargetZombieRenderer.java <==
package net.db64.homelawnsecurity.entity.client.zombie;

import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.entity.client.ModModelLayers;
import net.db64.homelawnsecurity.entity.custom.other.TargetZombieEntity;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5617;
import net.minecraft.class_927;

public class TargetZombieRenderer extends class_927<TargetZombieEntity, TargetZombieRenderState, TargetZombieModel> {
	private static final class_2960 TEXTURE = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/target_zombie.png");

	public TargetZombieRenderer(class_5617.class_5618 context) {
		super(context, new TargetZombieModel(context.method_32167(ModModelLayers.Zombie.TARGET_ZOMBIE)), 0.5f);
	}

	@Override
	public class_2960 getTexture(TargetZombieRenderState state) {
		return TEXTURE;
	}

	@Override
	public void render(TargetZombieRenderState state, class_4587 matrixStack, class_4597 vertexConsumerProvider, int i) {
		super.method_4054(state, matrixStack, vertexConsumerProvider, i);
	}

	@Override
	public TargetZombieRenderState method_55269() {
		return new TargetZombieRenderState();
	}

	@Override
	public void updateRenderState(TargetZombieEntity entity, TargetZombieRenderState state, float f) {
		super.method_62355(entity, state, f);

		state.hasLostArm = entity.hasTriggeredDegradationStage("arm");
		state.hasLostHead = entity.hasTriggeredDegradationStage("head");
		state.setupAnimationState.method_61401(entity.setupAnimationState);
		state.attackAnimationState.method_61401(entity.attackAnimationState);
	}
}

==> homelawnsecurity-0.0.5.2-sources.jar: net/db64/homelawnsecurity/entity/client/zombie/TargetZombieRenderer.java <==
package net.db64.homelawnsecurity.entity.client.zombie;

import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.entity.client.ModModelLayers;
import net.db64.homelawnsecurity.entity.custom.other.TargetZombieEntity;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_5617;
import net.minecraft.class_927;

public class TargetZombieRenderer extends class_927<TargetZombieEntity, TargetZombieRenderState, TargetZombieModel> {
	private static final class_2960 TEXTURE = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/target_zombie.png");

	public TargetZombieRenderer(class_5617.class_5618 context) {
		super(context, new TargetZombieModel(context.method_32167(ModModelLayers.Zombie.TARGET_ZOMBIE)), 0.5f);
	}

	@Override
	public class_2960 getTexture(TargetZombieRenderState state) {
		return TEXTURE;
	}

	@Override
	public void render(
		TargetZombieRenderState state,
		class_4587 matrixStack,
		class_11659 orderedRenderCommandQueue,
		class_12075 cameraRenderState
	) {
		super.method_4054(state, matrixStack, orderedRenderCommandQueue, cameraRenderState);
	}

	@Override
	public TargetZombieRenderState method_55269() {
		return new TargetZombieRenderState();
	}

	@Override
	public void updateRenderState(TargetZombieEntity entity, TargetZombieRenderState state, float f) {
		super.method_62355(entity, state, f);

		state.hasLostArm = entity.hasTriggeredDegradationStage("arm");
		state.hasLostHead = entity.hasTriggeredDegradationStage("head");
		state.setupAnimationState.method_61401(entity.setupAnimationState);
		state.attackAnimationState.method_61401(entity.attackAnimationState);
	}
}
